Learn R Programming

decp (version 0.1.2)

adjusted_ratio_bin_seg: Adjusted Ratio Binary Segmentation

Description

Adjusted ratio binary segmentation.

Usage

adjusted_ratio_bin_seg(input_data, minseglen, alpha)

Value

A list with change points and segments.

Arguments

input_data

A numeric matrix of observations for multivariate time series data where the dimension is not greater than the observations. Date columns should not be inputted.

minseglen

Minimum segment length for detecting change points.

alpha

Level of significance for calculating the confidence intervals.

Examples

Run this code
# Example usage
data <- matrix(rnorm(1000), ncol = 10)
result <- adjusted_ratio_bin_seg(data, minseglen = 30, alpha = 0.05)

Run the code above in your browser using DataLab