An object of class 'mle_change_point_result' containing the index of the change point estimate, its MLE value, and the MLE data.
Arguments
input_data
A numeric matrix of observations for multivariate time series
data where the dimension is not greater than the observations. Date columns should not be inputted.
verbose
Logical value indicating whether to print messages during the function execution. Default is TRUE.