A numeric matrix of observations for multivariate time series
data where the dimension is not greater than the observations. Date columns should not be inputted.
minseglen
Minimum segment length for detecting change points.
alpha
Level of significance for calculating the confidence intervals.